@@ -99,7 +99,8 @@ class LanguageTranslatorV3(WatsonService):
             iam_apikey=iam_apikey,
             iam_access_token=iam_access_token,
             iam_url=iam_url,
-            use_vcap_services=True)
+            use_vcap_services=True,
+            display_name='Language Translator')
         self.version = version
 
     #########################
@@ -130,6 +131,8 @@ class LanguageTranslatorV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=language_translator;service_version=V3;operation_id=translate'
 
         params = {'version': self.version}
 
@@ -172,6 +175,8 @@ class LanguageTranslatorV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=language_translator;service_version=V3;operation_id=identify'
 
         params = {'version': self.version}
 
@@ -203,6 +208,8 @@ class LanguageTranslatorV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=language_translator;service_version=V3;operation_id=list_identifiable_languages'
 
         params = {'version': self.version}
 
@@ -274,6 +281,8 @@ class LanguageTranslatorV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=language_translator;service_version=V3;operation_id=create_model'
 
         params = {
             'version': self.version,
@@ -325,6 +334,8 @@ class LanguageTranslatorV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=language_translator;service_version=V3;operation_id=delete_model'
 
         params = {'version': self.version}
 
@@ -357,6 +368,8 @@ class LanguageTranslatorV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=language_translator;service_version=V3;operation_id=get_model'
 
         params = {'version': self.version}
 
@@ -394,6 +407,8 @@ class LanguageTranslatorV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=language_translator;service_version=V3;operation_id=list_models'
 
         params = {
             'version': self.version,
