@@ -87,7 +87,8 @@ class NaturalLanguageClassifierV1(WatsonService):
             iam_apikey=iam_apikey,
             iam_access_token=iam_access_token,
             iam_url=iam_url,
-            use_vcap_services=True)
+            use_vcap_services=True,
+            display_name='Natural Language Classifier')
 
     #########################
     # Classify text
@@ -115,6 +116,8 @@ class NaturalLanguageClassifierV1(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=natural_language_classifier;service_version=V1;operation_id=classify'
 
         data = {'text': text}
 
@@ -152,6 +155,8 @@ class NaturalLanguageClassifierV1(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=natural_language_classifier;service_version=V1;operation_id=classify_collection'
 
         data = {'collection': collection}
 
@@ -190,7 +195,7 @@ class NaturalLanguageClassifierV1(WatsonService):
         :param file training_data: Training data in CSV format. Each text value must have
         at least one class. The data can include up to 3,000 classes and 20,000 records.
         For details, see [Data
-        preparation](https://console.bluemix.net/docs/services/natural-language-classifier/using-your-data.html).
+        preparation](https://cloud.ibm.com/docs/services/natural-language-classifier/using-your-data.html).
         :param str metadata_filename: The filename for training_metadata.
         :param str training_data_filename: The filename for training_data.
         :param dict headers: A `dict` containing the request headers
@@ -206,6 +211,8 @@ class NaturalLanguageClassifierV1(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=natural_language_classifier;service_version=V1;operation_id=create_classifier'
 
         form_data = {}
         if not metadata_filename and hasattr(metadata, 'name'):
@@ -242,6 +249,8 @@ class NaturalLanguageClassifierV1(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=natural_language_classifier;service_version=V1;operation_id=delete_classifier'
 
         url = '/v1/classifiers/{0}'.format(
             *self._encode_path_vars(classifier_id))
@@ -267,6 +276,8 @@ class NaturalLanguageClassifierV1(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=natural_language_classifier;service_version=V1;operation_id=get_classifier'
 
         url = '/v1/classifiers/{0}'.format(
             *self._encode_path_vars(classifier_id))
@@ -288,6 +299,8 @@ class NaturalLanguageClassifierV1(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=natural_language_classifier;service_version=V1;operation_id=list_classifiers'
 
         url = '/v1/classifiers'
         response = self.request(
