@@ -102,7 +102,8 @@ class ToneAnalyzerV3(WatsonService):
             iam_apikey=iam_apikey,
             iam_access_token=iam_access_token,
             iam_url=iam_url,
-            use_vcap_services=True)
+            use_vcap_services=True,
+            display_name='Tone Analyzer')
         self.version = version
 
     #########################
@@ -136,7 +137,7 @@ class ToneAnalyzerV3(WatsonService):
         text/plain;charset=utf-8`. For `text/html`, the service removes HTML tags and
         analyzes only the textual content.
         **See also:** [Using the general-purpose
-        endpoint](/docs/services/tone-analyzer/using-tone.html#using-the-general-purpose-endpoint).
+        endpoint](https://cloud.ibm.com/docs/services/tone-analyzer/using-tone.html#using-the-general-purpose-endpoint).
 
         :param ToneInput tone_input: JSON, plain text, or HTML input that contains the
         content to be analyzed. For JSON input, provide an object of type `ToneInput`.
@@ -181,6 +182,8 @@ class ToneAnalyzerV3(WatsonService):
         }
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=tone_analyzer;service_version=V3;operation_id=tone'
 
         params = {
             'version': self.version,
@@ -222,7 +225,7 @@ class ToneAnalyzerV3(WatsonService):
         utterances have more than 500 characters. Per the JSON specification, the default
         character encoding for JSON content is effectively always UTF-8.
         **See also:** [Using the customer-engagement
-        endpoint](/docs/services/tone-analyzer/using-tone-chat.html#using-the-customer-engagement-endpoint).
+        endpoint](https://cloud.ibm.com/docs/services/tone-analyzer/using-tone-chat.html#using-the-customer-engagement-endpoint).
 
         :param list[Utterance] utterances: An array of `Utterance` objects that provides
         the input content that the service is to analyze.
@@ -252,6 +255,8 @@ class ToneAnalyzerV3(WatsonService):
         }
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=tone_analyzer;service_version=V3;operation_id=tone_chat'
 
         params = {'version': self.version}
 
