@@ -83,7 +83,8 @@ class VisualRecognitionV3(WatsonService):
             iam_apikey=iam_apikey,
             iam_access_token=iam_access_token,
             iam_url=iam_url,
-            use_vcap_services=True)
+            use_vcap_services=True,
+            display_name='Visual Recognition')
         self.version = version
 
     #########################
@@ -105,32 +106,30 @@ class VisualRecognitionV3(WatsonService):
 
         Classify images with built-in or custom classifiers.
 
-        :param file images_file: An image file (.jpg, .png) or .zip file with images.
-        Maximum image size is 10 MB. Include no more than 20 images and limit the .zip
-        file to 100 MB. Encode the image and .zip file names in UTF-8 if they contain
+        :param file images_file: An image file (.gif, .jpg, .png, .tif) or .zip file with
+        images. Maximum image size is 10 MB. Include no more than 20 images and limit the
+        .zip file to 100 MB. Encode the image and .zip file names in UTF-8 if they contain
         non-ASCII characters. The service assumes UTF-8 encoding if it encounters
         non-ASCII characters.
         You can also include an image with the **url** parameter.
-        :param str accept_language: The language of the output class names. The full set
-        of languages is supported for the built-in classifier IDs: `default`, `food`, and
-        `explicit`. The class names of custom classifiers are not translated.
-        The response might not be in the specified language when the requested language is
-        not supported or when there is no translation for the class name.
-        :param str url: The URL of an image to analyze. Must be in .jpg, or .png format.
-        The minimum recommended pixel density is 32X32 pixels per inch, and the maximum
-        image size is 10 MB.
+        :param str accept_language: The desired language of parts of the response. See the
+        response for details.
+        :param str url: The URL of an image (.gif, .jpg, .png, .tif) to analyze. The
+        minimum recommended pixel density is 32X32 pixels, but the service tends to
+        perform better with images that are at least 224 x 224 pixels. The maximum image
+        size is 10 MB.
         You can also include images with the **images_file** parameter.
         :param float threshold: The minimum score a class must have to be displayed in the
-        response. Set the threshold to `0.0` to ignore the classification score and return
-        all values.
-        :param list[str] owners: The categories of classifiers to apply. Use `IBM` to
-        classify against the `default` general classifier, and use `me` to classify
-        against your custom classifiers. To analyze the image against both classifier
-        categories, set the value to both `IBM` and `me`.
-        The built-in `default` classifier is used if both **classifier_ids** and
-        **owners** parameters are empty.
-        The **classifier_ids** parameter overrides **owners**, so make sure that
+        response. Set the threshold to `0.0` to return all identified classes.
+        :param list[str] owners: The categories of classifiers to apply. The
+        **classifier_ids** parameter overrides **owners**, so make sure that
         **classifier_ids** is empty.
+        - Use `IBM` to classify against the `default` general classifier. You get the same
+        result if both **classifier_ids** and **owners** parameters are empty.
+        - Use `me` to classify against all your custom classifiers. However, for better
+        performance use **classifier_ids** to specify the specific custom classifiers to
+        apply.
+        - Use both `IBM` and `me` to analyze the image against both classifier categories.
         :param list[str] classifier_ids: Which classifiers to apply. Overrides the
         **owners** parameter. You can specify both custom and built-in classifier IDs. The
         built-in `default` classifier is used if both **classifier_ids** and **owners**
@@ -149,6 +148,8 @@ class VisualRecognitionV3(WatsonService):
         headers = {'Accept-Language': accept_language}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=watson_vision_combined;service_version=V3;operation_id=classify'
 
         params = {'version': self.version}
 
@@ -190,6 +191,7 @@ class VisualRecognitionV3(WatsonService):
                      url=None,
                      images_file_content_type=None,
                      images_filename=None,
+                     accept_language=None,
                      **kwargs):
         """
         Detect faces in images.
@@ -198,12 +200,13 @@ class VisualRecognitionV3(WatsonService):
         to the Face model was removed. The identity information refers to the `name` of
         the person, `score`, and `type_hierarchy` knowledge graph. For details about the
         enhanced Face model, see the [Release
-        notes](https://console.bluemix.net/docs/services/visual-recognition/release-notes.html#2april2018).
+        notes](https://cloud.ibm.com/docs/services/visual-recognition/release-notes.html#2april2018).
         Analyze and get data about faces in images. Responses can include estimated age
         and gender. This feature uses a built-in model, so no training is necessary. The
         Detect faces method does not support general biometric facial recognition.
         Supported image formats include .gif, .jpg, .png, and .tif. The maximum image size
-        is 10 MB. The minimum recommended pixel density is 32X32 pixels per inch.
+        is 10 MB. The minimum recommended pixel density is 32X32 pixels, but the service
+        tends to perform better with images that are at least 224 x 224 pixels.
 
         :param file images_file: An image file (gif, .jpg, .png, .tif.) or .zip file with
         images. Limit the .zip file to 100 MB. You can include a maximum of 15 images in a
@@ -213,20 +216,25 @@ class VisualRecognitionV3(WatsonService):
         characters.
         You can also include an image with the **url** parameter.
         :param str url: The URL of an image to analyze. Must be in .gif, .jpg, .png, or
-        .tif format. The minimum recommended pixel density is 32X32 pixels per inch, and
-        the maximum image size is 10 MB. Redirects are followed, so you can use a
+        .tif format. The minimum recommended pixel density is 32X32 pixels, but the
+        service tends to perform better with images that are at least 224 x 224 pixels.
+        The maximum image size is 10 MB. Redirects are followed, so you can use a
         shortened URL.
         You can also include images with the **images_file** parameter.
         :param str images_file_content_type: The content type of images_file.
         :param str images_filename: The filename for images_file.
+        :param str accept_language: The desired language of parts of the response. See the
+        response for details.
         :param dict headers: A `dict` containing the request headers
         :return: A `DetailedResponse` containing the result, headers and HTTP status code.
         :rtype: DetailedResponse
         """
 
-        headers = {}
+        headers = {'Accept-Language': accept_language}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=watson_vision_combined;service_version=V3;operation_id=detect_faces'
 
         params = {'version': self.version}
 
@@ -238,7 +246,7 @@ class VisualRecognitionV3(WatsonService):
                                         images_file_content_type or
                                         'application/octet-stream')
         if url:
-            form_data['url'] = (None, url)
+            form_data['url'] = (None, url, 'text/plain')
 
         url = '/v3/detect_faces'
         response = self.request(
@@ -306,6 +314,8 @@ class VisualRecognitionV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=watson_vision_combined;service_version=V3;operation_id=create_classifier'
 
         params = {'version': self.version}
 
@@ -353,6 +363,8 @@ class VisualRecognitionV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=watson_vision_combined;service_version=V3;operation_id=delete_classifier'
 
         params = {'version': self.version}
 
@@ -384,6 +396,8 @@ class VisualRecognitionV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=watson_vision_combined;service_version=V3;operation_id=get_classifier'
 
         params = {'version': self.version}
 
@@ -411,6 +425,8 @@ class VisualRecognitionV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=watson_vision_combined;service_version=V3;operation_id=list_classifiers'
 
         params = {'version': self.version, 'verbose': verbose}
 
@@ -431,10 +447,10 @@ class VisualRecognitionV3(WatsonService):
         """
         Update a classifier.
 
-        Update a custom classifier by adding new positive or negative classes (examples)
-        or by adding new images to existing classes. You must supply at least one set of
-        positive or negative examples. For details, see [Updating custom
-        classifiers](https://console.bluemix.net/docs/services/visual-recognition/customizing.html#updating-custom-classifiers).
+        Update a custom classifier by adding new positive or negative classes or by adding
+        new images to existing classes. You must supply at least one set of positive or
+        negative examples. For details, see [Updating custom
+        classifiers](https://cloud.ibm.com/docs/services/visual-recognition/customizing.html#updating-custom-classifiers).
         Encode all names in UTF-8 if they contain non-ASCII characters (.zip and image
         file names, and classifier and class names). The service assumes UTF-8 encoding if
         it encounters non-ASCII characters.
@@ -475,6 +491,8 @@ class VisualRecognitionV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=watson_vision_combined;service_version=V3;operation_id=update_classifier'
 
         params = {'version': self.version}
 
@@ -529,6 +547,8 @@ class VisualRecognitionV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=watson_vision_combined;service_version=V3;operation_id=get_core_ml_model'
 
         params = {'version': self.version}
 
@@ -555,7 +575,7 @@ class VisualRecognitionV3(WatsonService):
         You associate a customer ID with data by passing the `X-Watson-Metadata` header
         with a request that passes data. For more information about personal data and
         customer IDs, see [Information
-        security](https://console.bluemix.net/docs/services/visual-recognition/information-security.html).
+        security](https://cloud.ibm.com/docs/services/visual-recognition/information-security.html).
 
         :param str customer_id: The customer ID for which all data is to be deleted.
         :param dict headers: A `dict` containing the request headers
@@ -569,6 +589,8 @@ class VisualRecognitionV3(WatsonService):
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+        headers[
+            'X-IBMCloud-SDK-Analytics'] = 'service_name=watson_vision_combined;service_version=V3;operation_id=delete_user_data'
 
         params = {'version': self.version, 'customer_id': customer_id}
 
@@ -640,23 +662,34 @@ class ClassResult(object):
     Result of a class within a classifier.
 
     :attr str class_name: Name of the class.
+    Class names are translated in the language defined by the **Accept-Language** request
+    header for the build-in classifier IDs (`default`, `food`, and `explicit`). Class
+    names of custom classifiers are not translated. The response might not be in the
+    specified language when the requested language is not supported or when there is no
+    translation for the class name.
     :attr float score: Confidence score for the property in the range of 0 to 1. A higher
     score indicates greater likelihood that the class is depicted in the image. The
     default threshold for returning scores from a classifier is 0.5.
-    :attr str type_hierarchy: Knowledge graph of the property. For example,
+    :attr str type_hierarchy: (optional) Knowledge graph of the property. For example,
     `/fruit/pome/apple/eating apple/Granny Smith`. Included only if identified.
     """
 
-    def __init__(self, class_name, score, type_hierarchy):
+    def __init__(self, class_name, score, type_hierarchy=None):
         """
         Initialize a ClassResult object.
 
         :param str class_name: Name of the class.
+        Class names are translated in the language defined by the **Accept-Language**
+        request header for the build-in classifier IDs (`default`, `food`, and
+        `explicit`). Class names of custom classifiers are not translated. The response
+        might not be in the specified language when the requested language is not
+        supported or when there is no translation for the class name.
         :param float score: Confidence score for the property in the range of 0 to 1. A
         higher score indicates greater likelihood that the class is depicted in the image.
         The default threshold for returning scores from a classifier is 0.5.
-        :param str type_hierarchy: Knowledge graph of the property. For example,
-        `/fruit/pome/apple/eating apple/Granny Smith`. Included only if identified.
+        :param str type_hierarchy: (optional) Knowledge graph of the property. For
+        example, `/fruit/pome/apple/eating apple/Granny Smith`. Included only if
+        identified.
         """
         self.class_name = class_name
         self.score = score
@@ -678,10 +711,6 @@ class ClassResult(object):
                 'Required property \'score\' not present in ClassResult JSON')
         if 'type_hierarchy' in _dict:
             args['type_hierarchy'] = _dict.get('type_hierarchy')
-        else:
-            raise ValueError(
-                'Required property \'type_hierarchy\' not present in ClassResult JSON'
-            )
         return cls(**args)
 
     def _to_dict(self):
@@ -807,8 +836,9 @@ class ClassifiedImages(object):
     """
     Results for all images.
 
-    :attr int custom_classes: Number of custom classes identified in the images.
-    :attr int images_processed: Number of images processed for the API call.
+    :attr int custom_classes: (optional) Number of custom classes identified in the
+    images.
+    :attr int images_processed: (optional) Number of images processed for the API call.
     :attr list[ClassifiedImage] images: Classified images.
     :attr list[WarningInfo] warnings: (optional) Information about what might cause less
     than optimal output. For example, a request sent with a corrupt .zip file and a list
@@ -816,13 +846,19 @@ class ClassifiedImages(object):
     returned when there is no warning.
     """
 
-    def __init__(self, custom_classes, images_processed, images, warnings=None):
+    def __init__(self,
+                 images,
+                 custom_classes=None,
+                 images_processed=None,
+                 warnings=None):
         """
         Initialize a ClassifiedImages object.
 
-        :param int custom_classes: Number of custom classes identified in the images.
-        :param int images_processed: Number of images processed for the API call.
         :param list[ClassifiedImage] images: Classified images.
+        :param int custom_classes: (optional) Number of custom classes identified in the
+        images.
+        :param int images_processed: (optional) Number of images processed for the API
+        call.
         :param list[WarningInfo] warnings: (optional) Information about what might cause
         less than optimal output. For example, a request sent with a corrupt .zip file and
         a list of image URLs will still complete, but does not return the expected output.
@@ -839,16 +875,8 @@ class ClassifiedImages(object):
         args = {}
         if 'custom_classes' in _dict:
             args['custom_classes'] = _dict.get('custom_classes')
-        else:
-            raise ValueError(
-                'Required property \'custom_classes\' not present in ClassifiedImages JSON'
-            )
         if 'images_processed' in _dict:
             args['images_processed'] = _dict.get('images_processed')
-        else:
-            raise ValueError(
-                'Required property \'images_processed\' not present in ClassifiedImages JSON'
-            )
         if 'images' in _dict:
             args['images'] = [
                 ClassifiedImage._from_dict(x) for x in (_dict.get('images'))
@@ -898,8 +926,8 @@ class Classifier(object):
 
     :attr str classifier_id: ID of a classifier identified in the image.
     :attr str name: Name of the classifier.
-    :attr str owner: (optional) Unique ID of the account who owns the classifier. Returned
-    when verbose=`true`. Might not be returned by some requests.
+    :attr str owner: (optional) Unique ID of the account who owns the classifier. Might
+    not be returned by some requests.
     :attr str status: (optional) Training status of classifier.
     :attr bool core_ml_enabled: (optional) Whether the classifier can be downloaded as a
     Core ML model after the training status is `ready`.
@@ -909,11 +937,11 @@ class Classifier(object):
     that the classifier was created.
     :attr list[Class] classes: (optional) Classes that define a classifier.
     :attr datetime retrained: (optional) Date and time in Coordinated Universal Time (UTC)
-    that the classifier was updated. Returned when verbose=`true`. Might not be returned
-    by some requests. Identical to `updated` and retained for backward compatibility.
+    that the classifier was updated. Might not be returned by some requests. Identical to
+    `updated` and retained for backward compatibility.
     :attr datetime updated: (optional) Date and time in Coordinated Universal Time (UTC)
     that the classifier was most recently updated. The field matches either `retrained` or
-    `created`.  Returned when verbose=`true`. Might not be returned by some requests.
+    `created`. Might not be returned by some requests.
     """
 
     def __init__(self,
@@ -933,7 +961,7 @@ class Classifier(object):
         :param str classifier_id: ID of a classifier identified in the image.
         :param str name: Name of the classifier.
         :param str owner: (optional) Unique ID of the account who owns the classifier.
-        Returned when verbose=`true`. Might not be returned by some requests.
+        Might not be returned by some requests.
         :param str status: (optional) Training status of classifier.
         :param bool core_ml_enabled: (optional) Whether the classifier can be downloaded
         as a Core ML model after the training status is `ready`.
@@ -943,13 +971,11 @@ class Classifier(object):
         (UTC) that the classifier was created.
         :param list[Class] classes: (optional) Classes that define a classifier.
         :param datetime retrained: (optional) Date and time in Coordinated Universal Time
-        (UTC) that the classifier was updated. Returned when verbose=`true`. Might not be
-        returned by some requests. Identical to `updated` and retained for backward
-        compatibility.
+        (UTC) that the classifier was updated. Might not be returned by some requests.
+        Identical to `updated` and retained for backward compatibility.
         :param datetime updated: (optional) Date and time in Coordinated Universal Time
         (UTC) that the classifier was most recently updated. The field matches either
-        `retrained` or `created`.  Returned when verbose=`true`. Might not be returned by
-        some requests.
+        `retrained` or `created`. Might not be returned by some requests.
         """
         self.classifier_id = classifier_id
         self.name = name
@@ -1443,19 +1469,24 @@ class FaceGender(object):
     Information about the gender of the face.
 
     :attr str gender: Gender identified by the face. For example, `MALE` or `FEMALE`.
+    :attr str gender_label: The word for "male" or "female" in the language defined by the
+    **Accept-Language** request header.
     :attr float score: Confidence score in the range of 0 to 1. A higher score indicates
     greater confidence in the estimated value for the property.
     """
 
-    def __init__(self, gender, score):
+    def __init__(self, gender, gender_label, score):
         """
         Initialize a FaceGender object.
 
         :param str gender: Gender identified by the face. For example, `MALE` or `FEMALE`.
+        :param str gender_label: The word for "male" or "female" in the language defined
+        by the **Accept-Language** request header.
         :param float score: Confidence score in the range of 0 to 1. A higher score
         indicates greater confidence in the estimated value for the property.
         """
         self.gender = gender
+        self.gender_label = gender_label
         self.score = score
 
     @classmethod
@@ -1467,6 +1498,12 @@ class FaceGender(object):
         else:
             raise ValueError(
                 'Required property \'gender\' not present in FaceGender JSON')
+        if 'gender_label' in _dict:
+            args['gender_label'] = _dict.get('gender_label')
+        else:
+            raise ValueError(
+                'Required property \'gender_label\' not present in FaceGender JSON'
+            )
         if 'score' in _dict:
             args['score'] = _dict.get('score')
         else:
@@ -1479,6 +1516,8 @@ class FaceGender(object):
         _dict = {}
         if hasattr(self, 'gender') and self.gender is not None:
             _dict['gender'] = self.gender
+        if hasattr(self, 'gender_label') and self.gender_label is not None:
+            _dict['gender_label'] = self.gender_label
         if hasattr(self, 'score') and self.score is not None:
             _dict['score'] = self.score
         return _dict
