@@ -15,6 +15,7 @@
 import json as json_import
 import platform
 import os
+from os.path import dirname, isfile, join, expanduser, abspath
 import requests
 import sys
 from requests.structures import CaseInsensitiveDict
@@ -33,7 +34,13 @@ X_WATSON_AUTHORIZATION_TOKEN = 'X-Watson-Authorization-Token'
 AUTH_HEADER_DEPRECATION_MESSAGE = 'Authenticating with the X-Watson-Authorization-Token header is deprecated. The token continues to work with Cloud Foundry services, but is not supported for services that use Identity and Access Management (IAM) authentication.'
 ICP_PREFIX = 'icp-'
 APIKEY = 'apikey'
+URL = 'url'
+USERNAME = 'username'
+PASSWORD = 'password'
+IAM_APIKEY = 'iam_apikey'
+IAM_URL = 'iam_url'
 APIKEY_DEPRECATION_MESSAGE = 'Authenticating with apikey is deprecated. Move to using Identity and Access Management (IAM) authentication.'
+DEFAULT_CREDENTIALS_FILE_NAME = 'ibm-credentials.env'
 
 # Uncomment this to enable http debugging
 # try:
@@ -53,7 +60,6 @@ def load_from_vcap_services(service_name):
     else:
         return None
 
-
 class WatsonException(Exception):
     """
     Custom exception class for Watson Services.
@@ -147,6 +153,9 @@ def _convert_boolean_values(dictionary):
             [(k, _convert_boolean_value(v)) for k, v in dictionary.items()])
     return dictionary
 
+def _has_bad_first_or_last_char(str):
+    return str is not None and (str.startswith('{') or str.startswith('"') or str.endswith('}') or str.endswith('"'))
+
 def get_error_message(response):
     """
     Gets the error message from a JSON response.
@@ -212,7 +221,8 @@ class DetailedResponse(object):
 class WatsonService(object):
     def __init__(self, vcap_services_name, url, username=None, password=None,
                  use_vcap_services=True, api_key=None,
-                 iam_apikey=None, iam_access_token=None, iam_url=None):
+                 iam_apikey=None, iam_access_token=None, iam_url=None,
+                 display_name=None):
         """
         Loads credentials from the VCAP_SERVICES environment variable if
         available, preferring credentials explicitly
@@ -236,12 +246,17 @@ class WatsonService(object):
         self.token_manager = None
         self.verify = None # Indicates whether to ignore verifying the SSL certification
 
+        if _has_bad_first_or_last_char(self.url):
+            raise ValueError('The URL shouldn\'t start or end with curly brackets or quotes. '
+                             'Be sure to remove any {} and \" characters surrounding your URL')
+
         user_agent_string = 'watson-apis-python-sdk-' + __version__ # SDK version
         user_agent_string += ' ' + platform.system() # OS
         user_agent_string += ' ' + platform.release() # OS version
         user_agent_string += ' ' + platform.python_version() # Python version
         self.user_agent_header = {'user-agent': user_agent_string}
 
+        # 1. Credentials are passed in constructor
         if api_key is not None:
             self.set_api_key(api_key)
         elif username is not None and password is not None:
@@ -250,9 +265,18 @@ class WatsonService(object):
             else:
                 self.set_username_and_password(username, password)
         elif iam_access_token is not None or iam_apikey is not None:
-            self.set_token_manager(iam_apikey, iam_access_token, iam_url)
+            if iam_apikey and iam_apikey.startswith(ICP_PREFIX):
+                self.set_username_and_password(APIKEY, iam_apikey)
+            else:
+                self.set_token_manager(iam_apikey, iam_access_token, iam_url)
 
-        if use_vcap_services and not self.username and not self.api_key:
+        # 2. Credentials from credential file
+        if display_name and not self.username and not self.token_manager:
+            service_name = display_name.replace(' ', '_').lower()
+            self.load_from_credential_file(service_name)
+
+        # 3. Credentials from VCAP
+        if use_vcap_services and not self.username and not self.token_manager:
             self.vcap_service_credentials = load_from_vcap_services(
                 vcap_services_name)
             if self.vcap_service_credentials is not None and isinstance(
@@ -275,12 +299,64 @@ class WatsonService(object):
                 'You must specify your IAM api key or username and password service '
                 'credentials (Note: these are different from your Bluemix id)')
 
+    def load_from_credential_file(self, service_name, separator='='):
+        """
+        Initiates the credentials based on the credential file
+
+        :param str service_name: The service name
+        :param str separator: the separator for key value pair
+        """
+        # File path specified by an env variable
+        credential_file_path = os.getenv("IBM_CREDENTIALS_FILE")
+
+        # Home directory
+        if credential_file_path is None:
+            file_path = join(expanduser('~'), DEFAULT_CREDENTIALS_FILE_NAME)
+            if isfile(file_path):
+                credential_file_path = file_path
+
+        # Top-level of the project directory
+        if credential_file_path is None:
+            file_path = join(dirname(dirname(abspath(__file__))), DEFAULT_CREDENTIALS_FILE_NAME)
+            if isfile(file_path):
+                credential_file_path = file_path
+
+        if credential_file_path is not None:
+            with open(credential_file_path, 'r') as fp:
+                for line in fp:
+                    key_val = line.strip().split(separator)
+                    if len(key_val) == 2:
+                        self._set_credential_based_on_type(service_name, key_val[0].lower(), key_val[1].lower())
+
+
+    def _set_credential_based_on_type(self, service_name, key, value):
+        if service_name in key:
+            if APIKEY in key:
+                self.set_iam_apikey(value)
+            elif URL in key:
+                self.set_url(value)
+            elif USERNAME in key:
+                self.username = value
+            elif PASSWORD in key:
+                self.password = value
+            elif IAM_APIKEY in key:
+                self.set_iam_apikey(value)
+            elif IAM_URL in key:
+                self.set_iam_url(value)
+
     def set_username_and_password(self, username=None, password=None):
         if username == 'YOUR SERVICE USERNAME':
             username = None
         if password == 'YOUR SERVICE PASSWORD':
             password = None
 
+        if _has_bad_first_or_last_char(username):
+            raise ValueError('The username shouldn\'t start or end with curly brackets or quotes. '
+                             'Be sure to remove any {} and \" characters surrounding your username')
+        if _has_bad_first_or_last_char(password):
+            raise ValueError('The password shouldn\'t start or end with curly brackets or quotes. '
+                             'Be sure to remove any {} and \" characters surrounding your password')
+
         self.username = username
         self.password = password
         self.jar = CookieJar()
@@ -304,7 +380,9 @@ class WatsonService(object):
     def set_token_manager(self, iam_apikey=None, iam_access_token=None, iam_url=None):
         if iam_apikey == 'YOUR IAM API KEY':
             return
-
+        if _has_bad_first_or_last_char(iam_apikey):
+            raise ValueError('The credentials shouldn\'t start or end with curly brackets or quotes. '
+                             'Be sure to remove any {} and \" characters surrounding your credentials')
         self.iam_apikey = iam_apikey
         self.iam_access_token = iam_access_token
         self.iam_url = iam_url
@@ -319,7 +397,18 @@ class WatsonService(object):
         self.iam_access_token = iam_access_token
         self.jar = CookieJar()
 
+    def set_iam_url(self, iam_url):
+        if self.token_manager:
+            self.token_manager.set_iam_url(iam_url)
+        else:
+            self.token_manager = IAMTokenManager(iam_url=iam_url)
+        self.iam_url = iam_url
+        self.jar = CookieJar()
+
     def set_iam_apikey(self, iam_apikey):
+        if _has_bad_first_or_last_char(iam_apikey):
+            raise ValueError('The credentials shouldn\'t start or end with curly brackets or quotes. '
+                             'Be sure to remove any {} and \" characters surrounding your credentials')
         if self.token_manager:
             self.token_manager.set_iam_apikey(iam_apikey)
         else:
@@ -328,6 +417,9 @@ class WatsonService(object):
         self.jar = CookieJar()
 
     def set_url(self, url):
+        if _has_bad_first_or_last_char(url):
+            raise ValueError('The URL shouldn\'t start or end with curly brackets or quotes. '
+                             'Be sure to remove any {} and \" characters surrounding your URL')
         self.url = url
 
     def set_default_headers(self, headers):
